Struct wayland_client::protocol::wl_region::WlRegion [−][src]
pub struct WlRegion(_);Implementations
destroy region
Destroy the region. This will invalidate the object ID.
This is a destructor, you cannot send requests to this object any longer once this method is called.
add rectangle to region
Add the specified rectangle to the region.